geowatch.cli package
====================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   geowatch.cli.experimental
   geowatch.cli.queue_cli
   geowatch.cli.smartflow
   geowatch.cli.special

Submodules
----------

.. toctree::
   :maxdepth: 4

   geowatch.cli.animate_visualizations
   geowatch.cli.baseline_framework_ingress
   geowatch.cli.cluster_sites
   geowatch.cli.coco_add_ignore_buffer
   geowatch.cli.coco_add_watch_fields
   geowatch.cli.coco_align
   geowatch.cli.coco_average_features
   geowatch.cli.coco_clean_geotiffs
   geowatch.cli.coco_combine_features
   geowatch.cli.coco_crop_tracks
   geowatch.cli.coco_reformat_channels
   geowatch.cli.coco_remove_bad_images
   geowatch.cli.coco_spectra
   geowatch.cli.coco_time_combine
   geowatch.cli.coco_update_geotiff_metadata
   geowatch.cli.coco_visualize_videos
   geowatch.cli.collect_env
   geowatch.cli.concat_kwcoco_videos
   geowatch.cli.crop_sites_to_regions
   geowatch.cli.draw_region
   geowatch.cli.extend_sc_sites
   geowatch.cli.find_dvc
   geowatch.cli.fit
   geowatch.cli.fix_region_models
   geowatch.cli.geojson_site_stats
   geowatch.cli.geotiffs_to_kwcoco
   geowatch.cli.merge_region_models
   geowatch.cli.mlops_cli
   geowatch.cli.predict
   geowatch.cli.pseudolive_consolidate
   geowatch.cli.reproject_annotations
   geowatch.cli.run_fusion_predict
   geowatch.cli.run_metrics_framework
   geowatch.cli.run_tracker
   geowatch.cli.smartflow_egress
   geowatch.cli.smartflow_ingress
   geowatch.cli.split_videos
   geowatch.cli.stac_search
   geowatch.cli.stac_to_kwcoco
   geowatch.cli.torch_model_stats
   geowatch.cli.validate_annotation_schemas
   geowatch.cli.watch_coco_stats

Module contents
---------------

.. automodule:: geowatch.cli
   :members:
   :undoc-members:
   :show-inheritance:
